@@ -17,10 +17,11 @@ from glue.core.visual import VisualAttributes
 from glue.config import settings
 from glue.utils import view_shape
 
+__all__ = ['Subset', 'SubsetState', 'RoiSubsetState', 'CategoricalROISubsetState',
+           'RangeSubsetState', 'MultiRangeSubsetState', 'CompositeSubsetState',
+           'OrState', 'AndState', 'XorState', 'InvertState', 'MaskSubsetState', 'CategorySubsetState',
+           'ElementSubsetState', 'InequalitySubsetState', 'combine_multiple']
 
-__all__ = ['Subset', 'SubsetState', 'RoiSubsetState', 'CompositeSubsetState',
-           'OrState', 'AndState', 'XorState', 'InvertState',
-           'ElementSubsetState', 'RangeSubsetState', 'combine_multiple']
 
 OPSYM = {operator.ge: '>=', operator.gt: '>',
          operator.le: '<=', operator.lt: '<',
@@ -675,6 +676,13 @@ class ElementSubsetState(SubsetState):
     def copy(self):
         return ElementSubsetState(self._indices)
 
+    def __gluestate__(self, context):
+        return dict(indices=context.do(self._indices))
+
+    @classmethod
+    def __setgluestate__(cls, rec, context):
+        return cls(indices=context.object(rec['indices']))
+
 
 class InequalitySubsetState(SubsetState):
 
