@@ -1,20 +1,19 @@
-#pylint: disable=I0011,W0613,W0201,W0212,E1101,E1103
+# pylint: disable=I0011,W0613,W0201,W0212,E1101,E1103
 
 from __future__ import absolute_import, division, print_function
 
 import pytest
-
 import numpy as np
-from numpy.testing import assert_almost_equal
-from matplotlib.figure import Figure
-from glue.core.data import CategoricalComponent
 from mock import MagicMock
+from matplotlib.figure import Figure
+from numpy.testing import assert_almost_equal
 
-from ..roi import (RectangularROI, UndefinedROI, CircularROI, PolygonalROI, CategoricalRoi,
+from .. import roi as r
+from ..component import CategoricalComponent
+from ..roi import (RectangularROI, UndefinedROI, CircularROI, PolygonalROI, CategoricalROI,
                    MplCircularROI, MplRectangularROI, MplPolygonalROI, MplPickROI, PointROI,
                    XRangeROI, MplXRangeROI, YRangeROI, MplYRangeROI, RangeROI)
 
-from .. import roi as r
 
 FIG = Figure()
 AXES = FIG.add_subplot(111)
@@ -378,33 +377,32 @@ class TestCategorical(object):
 
     def test_empty(self):
 
-        roi = CategoricalRoi()
+        roi = CategoricalROI()
         assert not roi.defined()
 
     def test_defined(self):
 
-        nroi = CategoricalRoi(categories=['a', 'b', 'c'])
+        nroi = CategoricalROI(categories=['a', 'b', 'c'])
         assert nroi.defined()
         nroi.reset()
         assert not nroi.defined()
 
     def test_loads_from_components(self):
 
-        roi = CategoricalRoi()
+        roi = CategoricalROI()
         comp = CategoricalComponent(np.array(['a', 'a', 'b']))
         roi.update_categories(comp)
 
         np.testing.assert_array_equal(roi.categories,
                                       np.array(['a', 'b']))
 
-        roi = CategoricalRoi(categories=comp)
+        roi = CategoricalROI(categories=comp)
         np.testing.assert_array_equal(roi.categories,
                                       np.array(['a', 'b']))
 
-
     def test_applies_components(self):
 
-        roi = CategoricalRoi()
+        roi = CategoricalROI()
         comp = CategoricalComponent(np.array(['a', 'b', 'c']))
         roi.update_categories(CategoricalComponent(np.array(['a', 'b'])))
         contained = roi.contains(comp, None)
@@ -413,14 +411,13 @@ class TestCategorical(object):
 
     def test_from_range(self):
 
-        comp = CategoricalComponent(np.array(list('abcdefghijklmnopqrstuvwxyz')*2))
+        comp = CategoricalComponent(np.array(list('abcdefghijklmnopqrstuvwxyz') * 2))
 
-        roi = CategoricalRoi.from_range(comp, 6, 10)
+        roi = CategoricalROI.from_range(comp, 6, 10)
         np.testing.assert_array_equal(roi.categories,
                                       np.array(list('ghij')))
 
 
-
 class DummyEvent(object):
     def __init__(self, x, y, inaxes=True, key=None):
         self.inaxes = inaxes
@@ -889,9 +886,6 @@ class TestPickMpl(TestMpl):
     def test_patch_hidden_on_finalise(self):
         """No patch to test for."""
 
-    def test_patch_hidden_on_finalise(self):
-        """No patch to test for."""
-
     def test_canvas_syncs_properly(self):
         """No patch to test for."""
 
