@@ -8,19 +8,21 @@ Utility function to load a variety of python objects into glue
 
 from __future__ import absolute_import, division, print_function
 
-from contextlib import contextmanager
 import sys
+from contextlib import contextmanager
 
 import numpy as np
 
+from glue.external import six
+
+
 try:
-    from .core import Data
+    from glue.core import Data
 except ImportError:
     # let qglue import, even though this won't work
     # qglue will throw an ImportError
     Data = None
 
-from .external import six
 
 __all__ = ['qglue']
 
@@ -81,7 +83,7 @@ def _parse_data_numpy(data, label):
 
 
 def _parse_data_path(path, label):
-    from .core.data_factories import load_data, as_list
+    from glue.core.data_factories import load_data, as_list
 
     data = load_data(path)
     for d in as_list(data):
@@ -90,7 +92,7 @@ def _parse_data_path(path, label):
 
 
 def _parse_data_hdulist(data, label):
-    from .core.data_factories.fits import fits_reader
+    from glue.core.data_factories.fits import fits_reader
     return fits_reader(data, label=label)
 
 
@@ -131,9 +133,9 @@ except ImportError:
     pass
 
 
-def _parse_links(dc, links):
-    from .core.link_helpers import MultiLink
-    from .core import ComponentLink
+def parse_links(dc, links):
+    from glue.core.link_helpers import MultiLink
+    from glue.core import ComponentLink
 
     data = dict((d.label, d) for d in dc)
     result = []
@@ -208,10 +210,10 @@ def qglue(**kwargs):
         links = [(['balls.kg'], ['cones.lbs'], lb2kg, kg2lb)]
         qglue(balls=balls, cones=cones, links=links)
 
-    :returns: A :class:`~glue.qt.glue_application.GlueApplication` object
+    :returns: A :class:`~glue.app.qt.application.GlueApplication` object
     """
-    from .core import DataCollection
-    from glue.qt.glue_application import GlueApplication
+    from glue.core import DataCollection
+    from glue.app.qt import GlueApplication
 
     links = kwargs.pop('links', None)
 
@@ -220,7 +222,7 @@ def qglue(**kwargs):
         dc.extend(parse_data(data, label))
 
     if links is not None:
-        dc.add_link(_parse_links(dc, links))
+        dc.add_link(parse_links(dc, links))
 
     with restore_io():
         ga = GlueApplication(dc)
