@@ -1,13 +1,15 @@
 from __future__ import absolute_import, division, print_function
 
 from ..config import qt_client, link_function, data_factory
+from glue.tests.helpers import requires_qt
 
 
+@requires_qt
 def test_default_clients():
-    from glue.qt.widgets.image_widget import ImageWidget
-    from glue.qt.widgets.scatter_widget import ScatterWidget
-    from glue.qt.widgets.histogram_widget import HistogramWidget
-    import glue.config
+
+    from glue.viewers.image.qt import ImageWidget
+    from glue.viewers.scatter.qt import ScatterWidget
+    from glue.viewers.histogram.qt import HistogramWidget
 
     assert ImageWidget in qt_client
     assert ScatterWidget in qt_client
