@@ -1,14 +1,16 @@
 from __future__ import absolute_import, division, print_function
 
 import pytest
-from mock import patch, MagicMock
+from mock import patch
 
+from glue.tests.helpers import requires_qt
+
+from ..core import Data
 from ..main import (die_on_error, restore_session, load_data_files,
                     main, start_glue)
 
-from ..core import Data, DataCollection, Hub
-
 
+@requires_qt
 def test_die_on_error_exception():
     """Decorator should spawn a QMessageBox and exit"""
     with pytest.raises(SystemExit):
@@ -98,6 +100,7 @@ def test_invalid(cmd):
         main(cmd.split())
 
 
+@requires_qt
 @pytest.mark.parametrize(('glue', 'config', 'data'),
                          [('test.glu', None, None),
                           (None, 'test.py', None),
@@ -108,7 +111,7 @@ def test_start(glue, config, data):
     with patch('glue.main.restore_session') as rs:
         with patch('glue.config.load_configuration') as lc:
             with patch('glue.main.load_data_files') as ldf:
-                with patch('glue.qt.glue_application.GlueApplication') as ga:
+                with patch('glue.app.qt.GlueApplication') as ga:
                     with patch('glue.external.qt.QtGui') as qt:
 
                         rs.return_value = ga
