@@ -3,7 +3,8 @@ from __future__ import absolute_import, division, print_function
 import numpy as np
 import pandas as pd
 
-from ..external.six import string_types
+from glue.external.six import string_types
+
 
 __all__ = ['unique', 'shape_to_string', 'view_shape', 'stack_view',
            'coerce_numeric', 'check_sorted']
@@ -14,9 +15,17 @@ def unique(array):
     Return the unique elements of the array U, as well as
     the index array I such that U[I] == array
 
-    :param array: The array to use
-    :returns: U, I
-    :rtype: tuple of arrays
+    Parameters
+    ----------
+    array : `numpy.ndarray`
+        The array to use
+
+    Returns
+    -------
+    U : `numpy.ndarray`
+        The unique elements of the array
+    I : `numpy.ndarray`
+        The indices such that ``U[I] == array``
     """
     # numpy.unique doesn't handle mixed-types on python3,
     # so we use pandas
@@ -34,12 +43,17 @@ def shape_to_string(shape):
 
 
 def view_shape(shape, view):
-    """Return the shape of a view of an array
+    """
+    Return the shape of a view of an array.
 
-    :param shape: Tuple describing shape of the array
-    :param view: View object -- a valid index into a numpy array, or None
+    Returns equivalent of ``np.zeros(shape)[view].shape``
 
-    Returns equivalent of np.zeros(shape)[view].shape
+    Parameters
+    ----------
+    shape : tuple
+        The shape of the array
+    view : slice
+        A valid index into a Numpy array, or None
     """
     if view is None:
         return shape
@@ -64,16 +78,16 @@ def stack_view(shape, *views):
 
 
 def coerce_numeric(arr):
-    """Coerce an array into a numeric array, replacing
-       non-numeric elements with nans.
+    """
+    Coerce an array into a numeric array, replacing non-numeric elements with
+    nans.
 
-       If the array is already a numeric type, it is returned
-       unchanged
+    If the array is already a numeric type, it is returned unchanged
 
-       :param arr: array to coerce
-       :type arr: :class:`numpy.ndarray`
-
-       :returns: array.
+    Parameters
+    ----------
+    arr : `numpy.ndarray`
+        The array to coerce
     """
     # already numeric type
     if np.issubdtype(arr.dtype, np.number):
@@ -83,14 +97,47 @@ def coerce_numeric(arr):
         return arr.astype(np.int)
 
     # a string dtype, or anything else
-    return pd.Series(arr).convert_objects(convert_numeric=True).values
+    try:
+        return pd.to_numeric(arr, errors='coerce')
+    except AttributeError:  # older versions of pandas
+        return pd.Series(arr).convert_objects(convert_numeric=True).values
 
 
 def check_sorted(array):
-    """ Return True if the array is sorted, False otherwise.
+    """
+    Return `True` if the array is sorted, `False` otherwise.
     """
     # this ignores NANs, and does the right thing if nans
     # are concentrated at beginning or end of array
     # otherwise, it will miss things at nan/finite boundaries
     array = np.asarray(array)
     return not (array[:-1] > array[1:]).any()
+
+
+def pretty_number(numbers):
+    """
+    Convert a list/array of numbers into a nice list of strings
+
+    Parameters
+    ----------
+    numbers : list
+        The numbers to convert
+    """
+    try:
+        return [pretty_number(n) for n in numbers]
+    except TypeError:
+        pass
+
+    n = numbers
+    if n == 0:
+        result = '0'
+    elif (abs(n) < 1e-3) or (abs(n) > 1e3):
+        result = "%0.3e" % n
+    elif abs(int(n) - n) < 1e-3 and int(n) != 0:
+        result = "%i" % n
+    else:
+        result = "%0.3f" % n
+        if result.find('.') != -1:
+            result = result.rstrip('0')
+
+    return result
